# descripstats

This is a small package to help add more descriptive statistics to the default `describe()` of Pandas, which include:   
- mad: mean absolute deviation
- variance: variance
- sem: standard error of the mean
- sum: sum
- skewness: skewness
- kurtosis: kurtosis

Developed by Shouke Wei from Deepsim Academy, Deepsim Intelligence Technology Inc. (c) 2022

## Install the package
```python
pip install descripstats
```

## import the package
```python
from descripstats import Describe
```
then use the `Describe()` directly. Or 
```python
import descripstats as ds
```
then use `ds.Discribe()`

## Document
An example: https://github.com/shoukewei/descripstats/blob/main/docs/example.ipynb


